@@ -1,7 +1,10 @@
 use std::{env, fmt, num::NonZeroU8, str::FromStr, sync::Arc, time::Duration};
 
 use arrayvec::ArrayString;
-use reqwest::{header, StatusCode};
+use reqwest::{
+    header::{HeaderValue, AUTHORIZATION},
+    StatusCode,
+};
 use serde::{Deserialize, Serialize};
 use serde_repr::Deserialize_repr as DeserializeRepr;
 use serde_with::{
@@ -537,10 +540,19 @@ impl ApiActor {
         logger: Logger,
     ) -> ApiActor {
         // Build TLS backend that supports SSLKEYLOGFILE.
-        let mut tls = rustls::ClientConfig::new();
-        tls.set_protocols(&["h2".into(), "http/1.1".into()]);
-        tls.root_store
-            .add_server_trust_anchors(&webpki_roots::TLS_SERVER_ROOTS);
+        let mut root_store = rustls::RootCertStore::empty();
+        root_store.add_server_trust_anchors(webpki_roots::TLS_SERVER_ROOTS.0.iter().map(|ta| {
+            rustls::OwnedTrustAnchor::from_subject_spki_name_constraints(
+                ta.subject,
+                ta.spki,
+                ta.name_constraints,
+            )
+        }));
+        let mut tls = rustls::ClientConfig::builder()
+            .with_safe_defaults()
+            .with_root_certificates(root_store)
+            .with_no_client_auth();
+        tls.alpn_protocols = vec!["h2".into(), "http/1.1".into()];
         tls.key_log = Arc::new(rustls::KeyLogFile::new());
 
         ApiActor {
@@ -550,10 +562,12 @@ impl ApiActor {
                 .default_headers(
                     key.iter()
                         .map(|Key(k)| {
-                            (
-                                header::AUTHORIZATION,
-                                format!("Bearer {}", k).parse().expect("header value"),
-                            )
+                            (AUTHORIZATION, {
+                                let mut value = HeaderValue::from_str(&format!("Bearer {}", k))
+                                    .expect("bearer authorization");
+                                value.set_sensitive(true);
+                                value
+                            })
                         })
                         .collect(),
                 )
