@@ -1,6 +1,6 @@
 use std::{io, num::NonZeroU8, path::PathBuf, process::Stdio, time::Duration};
 
-use shakmaty::{fen::fen, variant::Variant};
+use shakmaty::variant::Variant;
 use tokio::{
     io::{AsyncBufReadExt as _, AsyncWriteExt as _, BufReader, BufWriter, Lines},
     process::{ChildStdin, ChildStdout, Command},
@@ -102,10 +102,11 @@ impl From<io::Error> for EngineError {
 
 #[cfg(unix)]
 fn new_process_group(command: &mut Command) -> &mut Command {
-    // Stop SIGINT from propagating to child process.
+    // SAFETY: The closure is run in a fork, and is not allowed to break
+    // invariants by using raw handles. Can be replaced with safe code once
+    // https://github.com/rust-lang/rust/issues/93857 is stabilized.
     unsafe {
-        // Safety: The closure is run in a fork, and is not allowed to break
-        // invariants by using raw handles.
+        // Stop SIGINT from propagating to child process.
         command.pre_exec(|| {
             if libc::setpgid(0, 0) == -1 {
                 Err(io::Error::last_os_error())
@@ -279,9 +280,7 @@ impl StockfishActor {
             .collect::<Vec<_>>()
             .join(" ");
         stdin
-            .write_all(
-                format!("position fen {} moves {}\n", fen(&position.root_fen), moves).as_bytes(),
-            )
+            .write_all(format!("position fen {} moves {}\n", position.root_fen, moves).as_bytes())
             .await?;
 
         // Go.
